@@ -98,6 +98,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cognito
@@ -328,6 +330,17 @@ class AuthenticateCognitoActionProps:
             CognitoStack(app, "integ-cognito")
             app.synth()
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AuthenticateCognitoActionProps.__init__)
+            check_type(argname="argument next", value=next, expected_type=type_hints["next"])
+            check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
+            check_type(argname="argument user_pool_client", value=user_pool_client, expected_type=type_hints["user_pool_client"])
+            check_type(argname="argument user_pool_domain", value=user_pool_domain, expected_type=type_hints["user_pool_domain"])
+            check_type(argname="argument authentication_request_extra_params", value=authentication_request_extra_params, expected_type=type_hints["authentication_request_extra_params"])
+            check_type(argname="argument on_unauthenticated_request", value=on_unauthenticated_request, expected_type=type_hints["on_unauthenticated_request"])
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument session_cookie_name", value=session_cookie_name, expected_type=type_hints["session_cookie_name"])
+            check_type(argname="argument session_timeout", value=session_timeout, expected_type=type_hints["session_timeout"])
         self._values: typing.Dict[str, typing.Any] = {
             "next": next,
             "user_pool": user_pool,
